@@ -49,8 +49,6 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#include <libgnome/gnome-desktop-item.h>
-
 #ifdef HAVE_STARTUP_NOTIFICATION
 #define SN_API_NOT_YET_FROZEN
 #include <libsn/sn.h>
@@ -61,6 +59,9 @@
 
 #define sure_string(s) ((s)!=NULL?(s):"")
 
+#undef GNOME_DISABLE_DEPRECATED
+#include <libgnome/gnome-desktop-item.h>
+
 struct _GnomeDesktopItem {
 	int refcount;
 
@@ -1544,7 +1545,8 @@ make_spawn_environment_for_sn_context (SnLauncherContext *sn_context,
  * timeouts. The reason our timeout is dumb is that we don't monitor
  * the sequence (don't use an SnMonitorContext)
  */
-#define STARTUP_TIMEOUT_LENGTH (30 /* seconds */ * 1000)
+#define STARTUP_TIMEOUT_LENGTH_SEC 30 /* seconds */
+#define STARTUP_TIMEOUT_LENGTH (STARTUP_TIMEOUT_LENGTH_SEC * 1000)
 
 typedef struct
 {
@@ -1609,12 +1611,16 @@ startup_timeout (void *data)
 		tmp = next;
 	}
 
+	/* we'll use seconds for the timeout */
+	if (min_timeout < 1000)
+		min_timeout = 1000;
+
 	if (std->contexts == NULL) {
 		std->timeout_id = 0;
 	} else {
-		std->timeout_id = g_timeout_add (min_timeout,
-						 startup_timeout,
-						 std);
+		std->timeout_id = g_timeout_add_seconds (min_timeout / 1000,
+							 startup_timeout,
+							 std);
 	}
 
 	/* always remove this one, but we may have reinstalled another one. */
@@ -1642,9 +1648,10 @@ add_startup_timeout (GdkScreen         *screen,
 	data->contexts = g_slist_prepend (data->contexts, sn_context);
 	
 	if (data->timeout_id == 0) {
-		data->timeout_id = g_timeout_add (STARTUP_TIMEOUT_LENGTH,
-						  startup_timeout,
-						  data);		
+		data->timeout_id = g_timeout_add_seconds (
+						STARTUP_TIMEOUT_LENGTH_SEC,
+						startup_timeout,
+						data);		
 	}
 }
 #endif /* HAVE_STARTUP_NOTIFICATION */
@@ -1731,6 +1738,7 @@ ditem_execute (const GnomeDesktopItem *item,
 	       gboolean use_current_dir,
 	       gboolean append_uris,
 	       gboolean append_paths,
+	       gboolean do_not_reap_child,
 	       GError **error)
 {
 	char **free_me = NULL;
@@ -1948,7 +1956,7 @@ ditem_execute (const GnomeDesktopItem *item,
 		if ( ! g_spawn_async (working_dir,
 				      real_argv,
 				      envp,
-				      G_SPAWN_SEARCH_PATH /* flags */,
+				      (do_not_reap_child ? G_SPAWN_DO_NOT_REAP_CHILD : 0) | G_SPAWN_SEARCH_PATH /* flags */,
 				      NULL, /* child_setup_func */
 				      NULL, /* child_setup_func_data */
 				      &ret /* child_pid */,
@@ -2101,6 +2109,7 @@ gnome_desktop_item_launch_on_screen_with_env (
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_USE_CURRENT_DIR),
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_APPEND_URIS),
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_APPEND_PATHS),
+			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_DO_NOT_REAP_CHILD),
 			     error);
 
 	return ret;
@@ -3126,7 +3135,6 @@ gnome_desktop_item_set_launch_time (GnomeDesktopItem *item,
 				    guint32           timestamp)
 {
 	g_return_if_fail (item != NULL);
-	g_return_if_fail (timestamp > 0);
 
 	item->launch_time = timestamp;
 }
